@@ -15,8 +15,8 @@ namespace waybar::modules::sway {
 class Scratchpad : public ALabel {
  public:
   Scratchpad(const std::string&, const Json::Value&);
-  ~Scratchpad() = default;
-  auto update() -> void;
+  virtual ~Scratchpad() = default;
+  auto update() -> void override;
 
  private:
   auto getTree() -> void;
@@ -32,4 +32,4 @@ class Scratchpad : public ALabel {
   Ipc ipc_;
   util::JsonParser parser_;
 };
-}  // namespace waybar::modules::sway
\ No newline at end of file
+}  // namespace waybar::modules::sway
